==> digikam-2.1.0.tar.bz2: digikam-2.1.0/extra/kipi-plugins/dngconverter/plugin/myimagelist.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2008-09-24
 * Description : file list view and items.
 *
 * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2011 by Veaceslav Munteanu <slavuttici at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "myimagelist.moc"

// KDE includes

#include <kdebug.h>
#include <klocale.h>
#include <kiconloader.h>

// KIPI includes

#include <libkipi/interface.h>

namespace KIPIDNGConverterPlugin
{

MyImageList::MyImageList(KIPI::Interface* iface, QWidget* parent)
    : ImagesList(iface, parent)
{
    setControlButtonsPlacement(ImagesList::ControlButtonsBelow);
    listView()->setColumnLabel(ImagesListView::Filename, i18n("Raw File"));
    listView()->setColumn(static_cast<KIPIPlugins::ImagesListView::ColumnType>(MyImageList::TARGETFILENAME),
                          i18n("Target File"), true);
    listView()->setColumn(static_cast<KIPIPlugins::ImagesListView::ColumnType>(MyImageList::IDENTIFICATION),
                          i18n("Camera"), true);
}

MyImageList::~MyImageList()
{
}

void MyImageList::slotAddImages(const KUrl::List& list)
{
    /* Replaces the ImagesList::slotAddImages method, so that
     * MyImageListViewItems can be added instead of ImagesListViewItems */

    // Figure out which of the supplied URL's should actually be added and which
    // of them already exist.
    bool found;

    for (KUrl::List::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
    {
        KUrl imageUrl = *it;
        found         = false;
        for (int i = 0; i < listView()->topLevelItemCount(); ++i)
        {
            MyImageListViewItem* currItem = dynamic_cast<MyImageListViewItem*>(listView()->topLevelItem(i));
            if (currItem && currItem->url() == imageUrl)
            {
                found = true;
                break;
            }
        }

        if (!found)
        {
            new MyImageListViewItem(listView(), imageUrl);
        }
    }

    // Duplicate the signalImageListChanged of the ImageWindow, to enable the
    // upload button again.
    emit signalImageListChanged();
}
void MyImageList::slotRemoveItems()
{
    bool find;
    do
    {
        find = false;
        QTreeWidgetItemIterator it(listView());
        while (*it)
        {
            MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(*it);
            if (item->isSelected())
            {
                delete item;
                find = true;
                break;
            }
        ++it;
        }
    }
    while(find);
}
// ------------------------------------------------------------------------------------------------

MyImageListViewItem::MyImageListViewItem(ImagesListView* view, const KUrl& url)
    : ImagesListViewItem(view, url)
{
}

MyImageListViewItem::~MyImageListViewItem()
{
}

void MyImageListViewItem::setDestFileName(const QString& str)
{
    m_destFileName = str;
    setText(MyImageList::TARGETFILENAME, m_destFileName);
}

QString MyImageListViewItem::destFileName() const
{
    return m_destFileName;
}

void MyImageListViewItem::setIdentity(const QString& str)
{
    m_identity = str;
    setText(MyImageList::IDENTIFICATION, m_identity);
}

QString MyImageListViewItem::identity() const
{
    return m_identity;
}

QString MyImageListViewItem::destPath() const
{
    QString path = url().directory() + "/" + destFileName();
    return path;
}

} // namespace KIPIDNGConverterPlugin

==> digikam-2.6.0.tar.bz2: digikam-2.6.0/extra/kipi-plugins/dngconverter/plugin/myimagelist.cpp <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.digikam.org
 *
 * Date        : 2008-09-24
 * Description : file list view and items.
 *
 * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2011      by Veaceslav Munteanu <slavuttici at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "myimagelist.moc"

// Qt includes

#include <QFileInfo>

// KDE includes

#include <kdebug.h>
#include <klocale.h>
#include <kiconloader.h>

// LibKDcraw includes

#include "kpmetadata.h"

namespace KIPIDNGConverterPlugin
{

MyImageList::MyImageList(QWidget* const parent)
    : KPImagesList(parent)
{
    setControlButtonsPlacement(KPImagesList::ControlButtonsBelow);
    listView()->setColumnLabel(KPImagesListView::Filename, i18n("Raw File"));
    listView()->setColumn(static_cast<KIPIPlugins::KPImagesListView::ColumnType>(TARGETFILENAME),
                          i18n("Target File"), true);
    listView()->setColumn(static_cast<KIPIPlugins::KPImagesListView::ColumnType>(IDENTIFICATION),
                          i18n("Camera"), true);
    listView()->setColumn(static_cast<KIPIPlugins::KPImagesListView::ColumnType>(STATUS),
                          i18n("Status"), true);
}

MyImageList::~MyImageList()
{
}

void MyImageList::slotAddImages(const KUrl::List& list)
{
    /* Replaces the KPImagesList::slotAddImages method, so that
     * MyImageListViewItems can be added instead of ImagesListViewItems */

    // Figure out which of the supplied URL's should actually be added and which
    // of them already exist.
    bool found = false;

    for (KUrl::List::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
    {
        KUrl imageUrl = *it;
        found         = false;
        for (int i = 0; i < listView()->topLevelItemCount(); ++i)
        {
            MyImageListViewItem* currItem = dynamic_cast<MyImageListViewItem*>(listView()->topLevelItem(i));
            if (currItem && currItem->url() == imageUrl)
            {
                found = true;
                break;
            }
        }

        if (!found && isValidRAWFile(imageUrl))
        {
            new MyImageListViewItem(listView(), imageUrl);
        }
    }

    // Duplicate the signalImageListChanged of the ImageWindow, to enable the
    // upload button again.
    emit signalImageListChanged();
}
void MyImageList::slotRemoveItems()
{
    bool find = false;
    do
    {
        find = false;
        QTreeWidgetItemIterator it(listView());
        while (*it)
        {
            MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(*it);
            if (item->isSelected())
            {
                delete item;
                find = true;
                break;
            }
        ++it;
        }
    }
    while(find);
}

bool MyImageList::isValidRAWFile(const KUrl& url) const
{
    if (KPMetadata::isRawFile(url))
    {
        QFileInfo fileInfo(url.path());
        if (fileInfo.suffix().toUpper() != QString("DNG"))
        {
            return true;
        }
    }

    return false;
}

// ------------------------------------------------------------------------------------------------

MyImageListViewItem::MyImageListViewItem(KPImagesListView* const view, const KUrl& url)
    : KPImagesListViewItem(view, url)
{
}

MyImageListViewItem::~MyImageListViewItem()
{
}

void MyImageListViewItem::setDestFileName(const QString& str)
{
    m_destFileName = str;
    setText(MyImageList::TARGETFILENAME, m_destFileName);
}

QString MyImageListViewItem::destFileName() const
{
    return m_destFileName;
}

void MyImageListViewItem::setIdentity(const QString& str)
{
    m_identity = str;
    setText(MyImageList::IDENTIFICATION, m_identity);
}

QString MyImageListViewItem::identity() const
{
    return m_identity;
}

void MyImageListViewItem::setStatus(const QString& str)
{
    m_status = str;
    setText(MyImageList::STATUS, m_status);
}

QString MyImageListViewItem::destPath() const
{
    QString path = url().directory() + QString("/") + destFileName();
    return path;
}

} // namespace KIPIDNGConverterPlugin
